///<reference path="../jspm_packages/npm/@types/systemjs@0.19.33/index.d.ts" />

import * as jsonfile from "jsonfile";

class PostInstall
{
    private tsconfig: any;
    private isProcessed: boolean = false;

    public process(): void
    {
        if (this.isProcessed === true) {
            return;
        }
        this.readTsConfig();
        this.clearPaths();
        this.injectSystemPaths();
        this.writeTsConfig();
        this.isProcessed = true;
    }

    private readTsConfig(): void
    {
        this.tsconfig = jsonfile.readFileSync("tsconfig.json", {});
    }

    private writeTsConfig(): void
    {
        jsonfile.writeFileSync("tsconfig.json", this.tsconfig, { spaces: 4 });
    }

    private injectSystemPaths(): void
    {
        let maps: any = SystemJS.map;
        for (let moduleName of Object.keys(maps)) {
            let modulePath: string = maps[moduleName];
            modulePath = modulePath.replace(new RegExp("^(npm|github)\:"), "$1/");
            modulePath = `jspm_packages/${modulePath}`;
            this.tsconfig.compilerOptions.paths[moduleName] = [modulePath];
        }
    }

    private clearPaths(): void
    {
        this.tsconfig.compilerOptions.paths = {};
    }
}

new PostInstall().process();